@@ -40,10 +40,10 @@ namespace Kwave
 	                QIODevice &dev, quint64 dev_offset);
 
 	/** Destructor */
-	virtual ~RecoveryMapping() {}
+        virtual ~RecoveryMapping() Q_DECL_OVERRIDE {}
 
 	/** implementation of Recoverysource::read */
-	qint64 read(quint64 offset, char *data, unsigned int bytes)
+        virtual qint64 read(quint64 offset, char *data, unsigned int bytes)
             Q_DECL_OVERRIDE;
 
     private:
